pub struct ClientCtx(/* private fields */);Expand description
A Kerberos client context
Implementations
Sourceimpl ClientCtx
impl ClientCtx
Sourcepub fn new(
flags: InitiateFlags,
principal: Option<&str>,
target_principal: &str,
channel_bindings: Option<&[u8]>,
) -> Result<(PendingClientCtx, impl Deref<Target = [u8]>)>
pub fn new( flags: InitiateFlags, principal: Option<&str>, target_principal: &str, channel_bindings: Option<&[u8]>, ) -> Result<(PendingClientCtx, impl Deref<Target = [u8]>)>
create a new client context for speaking to
target_principal. If principal is None then the
credentials of the user running current process will be
used. target_principal must be the service principal name of
the service you intend to communicate with. This should be an
spn as described by GSSAPI, e.g. service/host@REALM. If
present, channel_bindings is a service-specific channel
binding token which will be part of the initial communication
with the server.
On success a PendingClientCtx and a token to be sent to the
server will be returned. The server and client may generate
multiple additional tokens, which must be passed to the their
respective step methods until the initialization is
complete.
Examples found in repository?
examples/auth.rs (line 41)
39fn client(spn: &str, input: mpsc::Receiver<Msg>, output: mpsc::Sender<Msg>) {
40 let (mut client, token) =
41 ClientCtx::new(InitiateFlags::empty(), None, spn, None).expect("new");
42 output.send(Msg::Token(Bytes::copy_from_slice(&*token))).expect("send");
43 let mut client = loop {
44 let token = match input.recv().expect("expected data") {
45 Msg::Msg(_) => panic!("client not finished initializing"),
46 Msg::Token(t) => t,
47 };
48 match client.step(&*token).expect("step") {
49 Step::Finished((ctx, token)) => {
50 if let Some(token) = token {
51 output.send(Msg::Token(Bytes::copy_from_slice(&*token))).expect("send");
52 }
53 break ctx
54 },
55 Step::Continue((ctx, token)) => {
56 output.send(Msg::Token(Bytes::copy_from_slice(&*token))).expect("send");
57 client = ctx;
58 }
59 }
60 };
61 let msg = client.wrap(true, b"super secret message").expect("wrap");
62 output.send(Msg::Msg(Bytes::copy_from_slice(&*msg))).expect("send");
63}pub fn new_with_cred( cred: Cred, target_principal: &str, channel_bindings: Option<&[u8]>, ) -> Result<(PendingClientCtx, impl Deref<Target = [u8]>)>