pub struct ServerCtx(/* private fields */);Expand description
A Kerberos server context
Implementations
Sourceimpl ServerCtx
impl ServerCtx
Sourcepub fn new(
flags: AcceptFlags,
principal: Option<&str>,
channel_bindings: Option<&[u8]>,
) -> Result<PendingServerCtx>
pub fn new( flags: AcceptFlags, principal: Option<&str>, channel_bindings: Option<&[u8]>, ) -> Result<PendingServerCtx>
Create a new server context for principal, which should be
the service principal name assigned to the service the client
will be requesting. If it is left as None it will use the
user running the current process. The returned pending context
must be initiaized by exchanging one or more tokens with the
client before it can be used.
If present, channel_bindings must match the bindings the client
supplied to ClientCtx::new; the mechanism rejects the context
otherwise. Note that with a None acceptor binding the mechanism
generally accepts whatever the client sent, so to actually enforce
channel binding the server must pass its own expected bindings here.
Examples found in repository?
examples/auth.rs (line 22)
21fn server(spn: String, input: mpsc::Receiver<Msg>, output: mpsc::Sender<Msg>) {
22 let mut server = ServerCtx::new(AcceptFlags::empty(), Some(&spn), None).expect("new");
23 let mut server = loop {
24 let token = match input.recv().expect("expected data") {
25 Msg::Msg(_) => panic!("server not finished initializing"),
26 Msg::Token(t) => t,
27 };
28 match server.step(&*token).expect("step") {
29 Step::Finished((ctx, token)) => {
30 if let Some(token) = token {
31 output
32 .send(Msg::Token(Bytes::copy_from_slice(&*token)))
33 .expect("send");
34 }
35 break ctx;
36 }
37 Step::Continue((ctx, token)) => {
38 output.send(Msg::Token(Bytes::copy_from_slice(&*token))).expect("send");
39 server = ctx;
40 }
41 }
42 };
43 match input.recv().expect("expected data msg") {
44 Msg::Token(_) => panic!("unexpected extra token"),
45 Msg::Msg(secret_msg) => println!(
46 "{}",
47 String::from_utf8_lossy(&server.unwrap(&*secret_msg).expect("unwrap"))
48 ),
49 }
50}pub fn new_with_cred( flags: AcceptFlags, cred: Cred, channel_bindings: Option<&[u8]>, ) -> Result<PendingServerCtx>